summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/3rdparty/sqlite/where.c
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-09 22:25:47 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-09 22:25:47 -0500
commiteaa7ee2e0bbca40ba3173c4304f81957e8964291 (patch)
tree4f793aa48a5080aedc94ce6e519c3b86708f2b88 /tqtinterface/qt4/src/3rdparty/sqlite/where.c
parent79a9d7a46a20d4a0923bc06fc471fdc2176ef865 (diff)
downloadexperimental-eaa7ee2e0bbca40ba3173c4304f81957e8964291.tar.gz
experimental-eaa7ee2e0bbca40ba3173c4304f81957e8964291.zip
rename the following methods:
tqfind find tqreplace replace tqcontains contains
Diffstat (limited to 'tqtinterface/qt4/src/3rdparty/sqlite/where.c')
-rw-r--r--tqtinterface/qt4/src/3rdparty/sqlite/where.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/tqtinterface/qt4/src/3rdparty/sqlite/where.c b/tqtinterface/qt4/src/3rdparty/sqlite/where.c
index 097ec5b..3ab7eca 100644
--- a/tqtinterface/qt4/src/3rdparty/sqlite/where.c
+++ b/tqtinterface/qt4/src/3rdparty/sqlite/where.c
@@ -5,11 +5,11 @@
** a legal notice, here is a blessing:
**
** May you do good and not evil.
** May you tqfind forgiveness for yourself and forgive others.
** May you share freely, never taking more than you give.
**
*************************************************************************
-** This module tqcontains C code that generates VDBE code used to process
+** This module contains C code that generates VDBE code used to process
** the WHERE clause of SQL statements.
**
** $Id: where.c,v 1.89 2004/02/22 20:05:02 drh Exp $
@@ -190,7 +190,7 @@ static void exprAnalyze(ExprMaskSet *pMaskSet, ExprInfo *pInfo){
** left-most table in the FROM clause of that same SELECT statement and
** the table has a cursor number of "base".
**
** This routine attempts to tqfind an index for pTab that generates the
** correct record sequence for the given ORDER BY clause. The return value
** is a pointer to an index that does the job. NULL is returned if the
** table has no index that will generate the correct sort order.
@@ -207,7 +207,7 @@ static void exprAnalyze(ExprMaskSet *pMaskSet, ExprInfo *pInfo){
** *pbRev value is set to 1 if the ORDER BY clause is all DESC and it is
** set to 0 if the ORDER BY clause is all ASC.
*/
-static Index *tqfindSortingIndex(
+static Index *findSortingIndex(
Table *pTab, /* The table to be sorted */
int base, /* Cursor number for pTab */
ExprList *pOrderBy, /* The ORDER BY clause */
@@ -271,7 +271,7 @@ static Index *tqfindSortingIndex(
/*
** Generate the beginning of the loop used for WHERE clause processing.
-** The return value is a pointer to an (opaque) structure that tqcontains
+** The return value is a pointer to an (opaque) structure that contains
** information needed to terminate the loop. Later, the calling routine
** should invoke sqliteWhereEnd() with the return value of this function
** in order to complete the WHERE clause processing.
@@ -374,7 +374,7 @@ WhereInfo *sqliteWhereBegin(
/* Split the WHERE clause into separate subexpressions where each
** subexpression is separated by an AND operator. If the aExpr[]
** array fills up, the last entry might point to an expression which
- ** tqcontains additional unfactored AND operators.
+ ** contains additional unfactored AND operators.
*/
initMaskSet(&maskSet);
memset(aExpr, 0, sizeof(aExpr));
@@ -651,7 +651,7 @@ WhereInfo *sqliteWhereBegin(
pSortIdx = 0;
}else{
int nEqCol = (pWInfo->a[0].score+4)/8;
- pSortIdx = tqfindSortingIndex(pTab, pTabList->a[0].iCursor,
+ pSortIdx = findSortingIndex(pTab, pTabList->a[0].iCursor,
*ppOrderBy, pIdx, nEqCol, &bRev);
}
if( pSortIdx && (pIdx==0 || pIdx==pSortIdx) ){
@@ -5,11 +5,11 @@
**
** May you do good and not evil.
-** May you tqfind forgiveness for yourself and forgive others.
+** May you find forgiveness for yourself and forgive others.
** May you share freely, never taking more than you give.
**
@@ -190,7 +190,7 @@ static void exprAnalyze(ExprMaskSet *pMaskSet, ExprInfo *pInfo){
** the table has a cursor number of "base".
**
-** This routine attempts to tqfind an index for pTab that generates the
+** This routine attempts to find an index for pTab that generates the
** correct record sequence for the given ORDER BY clause. The return value
** is a pointer to an index that does the job. NULL is returned if the